import React,{Component} from 'react'
import {
  CCard,
  CCardBody,
  CCardHeader,
  CRow,
  CCol,
  CWidgetProgressIcon
} from '@coreui/react'
import {
  CChartBar,
  CChartPie,
  CChartDoughnut,
  CChartLine
} from '@coreui/react-chartjs'
import Session from '../../session';
import CIcon from '@coreui/icons-react';
import configuration from '../../config';

class Dashboard extends Component {
	constructor(props) {
        super(props);
        this.state = {
        	showLoader:false,
        	orders:[],
        	settings:{default_currency:'$'},
        	statistics:{
        		customer:0,
        		driver:0,
        		category:0,
        		vehicles:0,
        		package:0,
        		order:0
        	},
        	earnings:[],
        	sales:[]
        };
    }

    componentDidMount(){
		fetch(configuration.baseURL+"settings/get").then((response) => {
			return response.json();
		}).then((data) => {
			this.setState({ settings: data.payload});
		});
	}

    render() {
	  	return (
	  		<div>
	  			<Session/>
		  		<CRow>
		  			<CCol xs="12" md="6">
					    <CCard>
				        	<CCardHeader>
				          		Earnings
				        	</CCardHeader>
				        	<CCardBody>
					          	<CChartBar
					            	datasets={[
						              	{
							                label: 'Total Earnings',
							                backgroundColor: '#292d78',
							                data: this.state.earnings
						              	}
					            	]}
					            	labels="months"
					            	options={{
					              		tooltips: {
					                		enabled: true
					              		}
					            	}}
					          	/>
				        	</CCardBody>
				      	</CCard>
				    </CCol>
				    <CCol xs="12" md="6">  	
				      	<CCard>
				        	<CCardHeader>
				          		Sales
				        	</CCardHeader>
				        	<CCardBody>
					          	<CChartLine
						            datasets={[
						              	{
							                label: 'Total Sales',
							                backgroundColor: 'rgb(228,102,81,0.9)',
							                data: this.state.sales
						              	}
						            ]}
						            options={{
						              	tooltips: {
						                	enabled: true
						              	}
						            }}
						            labels="months"
						        />
				        	</CCardBody>
				      	</CCard>
				    </CCol>
		  		</CRow>
		  		<CRow>
			        <CCol sm="6" md="2">
				        <CWidgetProgressIcon
				            header={this.state.statistics.customer}
				            text="Customers"
				            color="gradient-info"
				            inverse
				         >
			            	<CIcon name="cil-people" height="36"/>
			          	</CWidgetProgressIcon>
			        </CCol>
			        <CCol sm="6" md="2">
			          	<CWidgetProgressIcon
				            header={this.state.statistics.driver}
				            text="Drivers"
				            color="gradient-success"
				            inverse
			          	>
			            	<CIcon name="cil-userFollow" height="36"/>
			          	</CWidgetProgressIcon>
			        </CCol>
			        <CCol sm="6" md="2">
			          	<CWidgetProgressIcon
				            header={this.state.statistics.vehicles}
				            text="Vehicles"
				            color="gradient-warning"
				            inverse
			          	>
			            	<CIcon name="cil-basket" height="36"/>
			          	</CWidgetProgressIcon>
			        </CCol>
			        <CCol sm="6" md="2">
			          	<CWidgetProgressIcon
				            header={this.state.statistics.category}
				            text="Service Categories"
				            color="gradient-primary"
				            inverse
			          	>
			            	<CIcon name="cil-chartPie" height="36"/>
			          	</CWidgetProgressIcon>
			        </CCol>
			        <CCol sm="6" md="2">
			          	<CWidgetProgressIcon
				            header={this.state.statistics.order}
				            text="Orders"
				            color="gradient-danger"
				            inverse
			          	>
			            	<CIcon name="cil-speedometer" height="36"/>
			          	</CWidgetProgressIcon>
			        </CCol>
			        <CCol sm="6" md="2">
			          	<CWidgetProgressIcon
				            header={this.state.statistics.package}
				            text="Packages"
				            color="gradient-info"
				            inverse
			          	>
			            	<CIcon name="cil-speech" height="36"/>
			          	</CWidgetProgressIcon>
			        </CCol>
		      	</CRow>
				<CRow>
				    <CCol xs="12" md="6">  	
				      	<CCard>
				        	<CCardHeader>
				          		Pie Chart
				        	</CCardHeader>
				        	<CCardBody>
					          	<CChartPie
						            datasets={[
						              	{
							                backgroundColor: [
							                  '#41B883',
							                  '#E46651',
							                  '#00D8FF',
							                  '#DD1B16'
							                ],
							                data: [40, 20, 80, 10]
						              	}
						            ]}
						            labels={['VueJs', 'EmberJs', 'ReactJs', 'AngularJs']}
						            options={{
						              	tooltips: {
						                	enabled: true
						              	}
						            }}
						        />
				        	</CCardBody>
				      	</CCard>
				    </CCol>
				    <CCol xs="12" md="6">  	
				      	<CCard>
				        	<CCardHeader>
				          		Doughnut Chart
				        	</CCardHeader>
				        	<CCardBody>
					          	<CChartDoughnut
						            datasets={[
						              	{
							                backgroundColor: [
							                  '#41B883',
							                  '#E46651',
							                  '#00D8FF',
							                  '#DD1B16'
							                ],
							                data: [40, 20, 80, 10]
						              	}
						            ]}
						            labels={['VueJs', 'EmberJs', 'ReactJs', 'AngularJs']}
						            options={{
						              	tooltips: {
						                	enabled: true
						              	}
						            }}
						        />
				        	</CCardBody>
				      	</CCard>
				    </CCol>
		  		</CRow>    	
		  	</div>	
	  	)
    }
}

export default Dashboard
