import React, {Component} from 'react'
import {
  CCol,
  CRow,
  CButton,
  CCard,
  CCardBody,
  CCardFooter,
  CFormGroup,
  CForm,
  CLabel,
  CInput,
  CFormText,
  CSelect
} from '@coreui/react'
import configuration from '../../config';
import { Editor } from '@tinymce/tinymce-react';
let help_id;


class edit extends Component {
	constructor(props) {
        super(props);
        this.state = {
        	showLoader:false,
        	fields:{},
        	errors:{},
        	languages:[],
        	categories:[]
        };
    }

    handleCancel(){
    	this.props.history.push('/help/view')
    }

    handleChange(field, e){
    	let fields = this.state.fields
    	fields[field] = e.target.value;
    	this.setState({fields})
    }

    editorChange(field, e){     
        let fields = this.state.fields;
        fields[field] = e;        
        this.setState({fields});
    }

    validation(){
    	let fields = this.state.fields;
    	let languages = this.state.languages;
        let errors = {};
        let formIsValid = true;

        if(!fields["help_category_id"]){
            formIsValid = false;
            errors["help_category_id"] = "Please select category.";
        }
        if(!fields["status"]){
            formIsValid = false;
            errors["status"] = "Please select status.";
        }
        for(var i=0; i<languages.length; i++){
            if(!fields[languages[i]['code']]){
                formIsValid = false;
            	errors[languages[i]['code']] = "Please enter question.";
            }
        }
        for(var k=0; k<languages.length; k++){
            if(!fields["ans_"+languages[k]['code']]){
                formIsValid = false;
            	errors["ans_"+languages[k]['code']] = "Please enter answer.";
            }
        }

        this.setState({errors: errors});
        return formIsValid;
    }

	submit() {
		if(this.validation()){
			this.setState({showLoader:true})
			fetch(configuration.baseURL+"help/update", {
				method: "post",
				headers: {
					'Accept': 'application/json',
					'Content-Type': 'application/json'
				},
				body:JSON.stringify(this.state.fields)
			}).then((response) => {
				return response.json();
			}).then((data) => {
				this.setState({showLoader:false})
				this.handleCancel()
			});
		}
	}

	componentWillMount(){
		var url = window.location.href;
        help_id=url.substring(url.lastIndexOf('/') + 1);
		
		fetch(configuration.baseURL+"help/get?help_id="+help_id).then((response) =>{
	    	return response.json();
	    }).then((data)=> {
	   		this.setState({ fields: data.payload, chart:data.payload.chart});
	    });

	    fetch(configuration.baseURL+"language/get?status=active").then((response) => {
			return response.json();
		}).then((data) => {
			this.setState({ languages: data.payload});
		});

		fetch(configuration.baseURL+"help-category/get?status=active").then((response) => {
			return response.json();
		}).then((data) => {
			this.setState({ categories: data.payload});
		}); 
	}

    render() {
	  	return (
	  		<CRow>
	  			<div className="loader-img" style={{display: this.state.showLoader ? 'block' : 'none' }}></div>
        		<CCol xs="12" md="12">
          			<CCard>
	            		<CCardBody>
	            			<CForm className="form-horizontal">
				                <CFormGroup row>
				                	<CCol md="6">
				                    	<CLabel htmlFor="hf-Type">Help Category</CLabel>
				                    	<CSelect custom onChange={this.handleChange.bind(this,'help_category_id')} value={this.state.fields.help_category_id}>
					                      	<option value="">--Select Category--</option>
					                      	{
	                                            this.state.categories.map((e, key) => {
	                                                return <option key={key} value={e.help_category_id}>{e.title.EN} --> {e.type}</option>;
	                                            })
	                                        }
					                    </CSelect>
		                    			<CFormText className="help-block">{this.state.errors['help_category_id']}</CFormText>
				                  	</CCol>
				                  	{
                                        this.state.languages.map((e, key) => {
                                            return <CCol md="6" key={key}>
						                    	<CLabel htmlFor="hf-Type">Question [ {e.title} ]</CLabel>
						                    	<CInput key={key} type="text" placeholder="Enter question" onChange={this.handleChange.bind(this, e.code)} value={this.state.fields[e.code]} />
				                    			<CFormText className="help-block">{this.state.errors[e.code]}</CFormText>
						                  	</CCol>;
                                        })
                                    }
				                </CFormGroup>
				                <CFormGroup row>
				                  	{
                                        this.state.languages.map((e, key) => {
                                            return <CCol md="12" key={key}>
						                    	<CLabel htmlFor="hf-Type">Answer [ {e.title} ]</CLabel>
						                    	<Editor
		                                            initialValue={this.state.fields["ans_"+e.code]}
		                                            onEditorChange={this.editorChange.bind(this, "ans_"+e.code)}
		                                            apiKey="igva2c4yldv4g644to94soo60vgck4nzy8pzt7z043yg9dwh"
		                                            init={{
											           	height: 500,
											           	menubar: false,
											           	plugins: [
											             	'advlist autolink lists link image charmap print preview anchor',
											             	'searchreplace visualblocks code fullscreen',
											             	'insertdatetime media table paste code help wordcount'
											           	],
											           	toolbar: 'undo redo | formatselect | bold italic backcolor | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | removeformat | help | code'
											        }}
			                                    />
				                    			<CFormText className="help-block">{this.state.errors['ans_'+e.code]}</CFormText>
						                  	</CCol>;
                                        })
                                    }
				                </CFormGroup>
				                <CFormGroup row>
				                  	<CCol md="6">
				                    	<CLabel htmlFor="hf-Status">Status</CLabel>
				                    	<CSelect custom onChange={this.handleChange.bind(this,'status')} value={this.state.fields.status}>
					                      	<option value="">--Select Status--</option>
					                      	<option value="active">Active</option>
					                      	<option value="inactive">Inactive</option>
					                    </CSelect>
				                    	<CFormText className="help-block">{this.state.errors.status}</CFormText>
				                  	</CCol>
				                </CFormGroup>
				            </CForm>
			            </CCardBody>
			            <CCardFooter>
			            	<CButton color="primary" className="px-4" onClick={this.submit.bind(this)}>Submit</CButton>{' '}
			            	<CButton color="danger" className="px-4" onClick={this.handleCancel.bind(this)}>Cancel</CButton>
			            </CCardFooter>
		            </CCard>
		        </CCol>  
		    </CRow>      
	  	)
    }
}

export default edit
