import React,{Component} from 'react'
import {
  CCard,
  CCardBody,
  CRow,
  CCol,
  CNav,
  CNavItem,
  CNavLink,
  CTabs,
  CTabPane,
  CTabContent,
  CForm,
  CFormGroup,
  CLabel,
  CInput,
  CCardFooter,
  CButton,
  CSelect
} from '@coreui/react'
import configuration from '../../config';
import {ToastContainer, toast} from 'react-toastify';
import 'react-toastify/dist/ReactToastify.css';


class Settings extends Component {
	constructor(props) {
        super(props);
        this.state = {
        	showLoader:false,
        	fields:{},
        	currencies:[]
        };
    }

    handleChange(field, e){
    	let fields = this.state.fields
    	fields[field] = e.target.value;
    	this.setState({fields})
    }

    componentDidMount(){
    	fetch(configuration.baseURL+"settings/get").then((response) => {
			return response.json();
		}).then((data) => {
			this.setState({ fields: data.payload});
		});

		fetch(configuration.baseURL+"currency/get?status=active").then((response) =>{
	    	return response.json();
	    }).then((data)=> {
	   		this.setState({ currencies: data.payload});
	    });
    }

    submit(){
    	this.setState({showLoader:true})
		fetch(configuration.baseURL+"settings/update", {
			method: "post",
			headers: {
				'Accept': 'application/json',
				'Content-Type': 'application/json'
			},
			body:JSON.stringify(this.state.fields)
		}).then((response) => {
			return response.json();
		}).then((data) => {
			this.setState({showLoader:false})
			return toast.success('Data updated successfully.');
		});
    }

    render() {
	  	return (
		    <CRow>
		    	<ToastContainer position="top-right" autoClose={5000} style={{top:'80px'}}/>
	  			<div className="loader-img" style={{display: this.state.showLoader ? 'block' : 'none' }}></div>
        		<CCol xs="12" md="12">
          			<CCard>
	            		<CCardBody>
	            			<CTabs>
				              	<CNav variant="tabs">
					                <CNavItem>
					                  	<CNavLink>
					                    	General
					                  	</CNavLink>
					                </CNavItem>
					                <CNavItem>
					                  	<CNavLink>
					                    	Social
					                  	</CNavLink>
					                </CNavItem>
				              	</CNav>
				              	<CTabContent>
					                <CTabPane>
					                  	<CRow>
					                		<CCol xs="12" md="12">
					                			<CCard>
	            									<CCardBody>
									                  	<CForm className="form-horizontal">
											                <CFormGroup row>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-title">Call US</CLabel>
											                    	<CInput type="text" placeholder="Enter mobile number" onChange={this.handleChange.bind(this,'call_us')} value={this.state.fields.call_us} />
											                  	</CCol>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-code">Support Email</CLabel>
											                    	<CInput type="text" placeholder="Enter email" onChange={this.handleChange.bind(this,'support_email')} value={this.state.fields.support_email} />
											                  	</CCol>
											                </CFormGroup>
											                <CFormGroup row>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-title">Tax (%)</CLabel>
											                    	<CInput type="number" placeholder="Enter tax percentage" onChange={this.handleChange.bind(this,'tax_percentage')} value={this.state.fields.tax_percentage} />
											                  	</CCol>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-title">Default Currency</CLabel>
											                    	<CSelect custom onChange={this.handleChange.bind(this,'default_currency')} value={this.state.fields.default_currency}>
												                      	<option value="">--Select Currency--</option>
												                      	{
								                                            this.state.currencies.map((e, key) => {
								                                                return <option key={key} value={e.symbol}>{e.name}</option>;
								                                            })
								                                        }
												                    </CSelect>
											                  	</CCol>
											                </CFormGroup>
											                <CFormGroup row>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-title">Compnay Address</CLabel>
											                    	<CInput type="text" placeholder="Enter address" onChange={this.handleChange.bind(this,'company_address')} value={this.state.fields.company_address} />
											                  	</CCol>
											                </CFormGroup>
											                <CFormGroup row>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-title">Company Percentage (%)</CLabel>
											                    	<CInput type="number" placeholder="Enter company percentage" onChange={this.handleChange.bind(this,'company_percentage')} value={this.state.fields.company_percentage} />
											                  	</CCol>
											                </CFormGroup>
											            </CForm>    
	            									</CCardBody>
	            									<CCardFooter>
										            	<CButton color="primary" className="px-4" onClick={this.submit.bind(this)}>Submit</CButton>{' '}
										            </CCardFooter>
	            								</CCard>	
					                		</CCol>
					                	</CRow>
					                </CTabPane>
					                <CTabPane>
					                	<CRow>
					                		<CCol xs="12" md="12">
					                			<CCard>
	            									<CCardBody>
									                  	<CForm className="form-horizontal">
											                <CFormGroup row>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-title">Facebook URL</CLabel>
											                    	<CInput type="text" placeholder="Enter fb url" onChange={this.handleChange.bind(this,'fb_url')} value={this.state.fields.fb_url} />
											                  	</CCol>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-code">Twitter URL</CLabel>
											                    	<CInput type="text" placeholder="Enter twitter url" onChange={this.handleChange.bind(this,'twitter_url')} value={this.state.fields.twitter_url} />
											                  	</CCol>
											                </CFormGroup>
											                <CFormGroup row>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-title">LinkedIn URL</CLabel>
											                    	<CInput type="text" placeholder="Enter linkedin url" onChange={this.handleChange.bind(this,'linkedin_url')} value={this.state.fields.linkedin_url} />
											                  	</CCol>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-code">Instagram URL</CLabel>
											                    	<CInput type="text" placeholder="Enter instagram url" onChange={this.handleChange.bind(this,'instagram_url')} value={this.state.fields.instagram_url} />
											                  	</CCol>
											                </CFormGroup>
											                <CFormGroup row>
											                  	<CCol md="6">
											                    	<CLabel htmlFor="hf-title">Youtube URL</CLabel>
											                    	<CInput type="text" placeholder="Enter Youtube url" onChange={this.handleChange.bind(this,'youtube_url')} value={this.state.fields.youtube_url} />
											                  	</CCol>
											                </CFormGroup>
											            </CForm>    
	            									</CCardBody>
	            									<CCardFooter>
										            	<CButton color="primary" className="px-4" onClick={this.submit.bind(this)}>Submit</CButton>{' '}
										            </CCardFooter>
	            								</CCard>	
					                		</CCol>
					                	</CRow>
					                </CTabPane>
				              	</CTabContent>
				            </CTabs>
			            </CCardBody>
		            </CCard>
		        </CCol>
		    </CRow> 
	  	)
    }
}

export default Settings
